@@ -12,10 +12,9 @@ from PIL import ImageTk, Image
 
 from .globals import ICON_APP, GITHUB_URL
 from .strings import ABOUTTXT, COPYRIGHTTXT, DLGABOUT
-
-from ._version import __version__
-
-VERSION = __version__
+from pynmea2 import version as PNVERSION
+from pyubx2 import version as PUVERSION
+from ._version import __version__ as VERSION
 
 
 class AboutDialog():
@@ -51,7 +50,14 @@ class AboutDialog():
         self._lbl_icon = Label(self._dialog, image=self._img_icon)
         self._lbl_desc = Label(self._dialog, text=ABOUTTXT, wraplength=250,
                                font=self.__app.font_sm)
-        self._lbl_version = Label(self._dialog, text="Version: " + VERSION, font=self.__app.font_sm)
+        self._lbl_version = Label(self._dialog, text="Version: " + VERSION,
+                                  font=self.__app.font_sm)
+        self._lbl_pyubx2_version = Label(self._dialog,
+                                         text="pyubx2 Version: " + PUVERSION,
+                                         font=self.__app.font_sm)
+        self._lbl_pynmea2_version = Label(self._dialog,
+                                          text="pynmea2 Version: " + PNVERSION,
+                                          font=self.__app.font_sm)
         self._lbl_copyright = Label(self._dialog, text=COPYRIGHTTXT, fg="blue",
                                     font=self.__app.font_sm, cursor="hand2")
         self._btn_ok = Button(self._dialog, text="OK", width=8, command=self.ok_press,
@@ -65,9 +71,11 @@ class AboutDialog():
         self._lbl_title.grid(column=0, row=0, padx=5, pady=3)
         self._lbl_icon.grid(column=0, row=1, padx=5, pady=3)
         self._lbl_desc.grid(column=0, row=2, padx=5, pady=3)
-        self._lbl_version.grid(column=0, row=3, padx=5, pady=3)
-        self._lbl_copyright.grid(column=0, row=4, padx=5, pady=3)
-        self._btn_ok.grid(column=0, row=5, ipadx=3, ipady=3, padx=5, pady=3)
+        self._lbl_version.grid(column=0, row=3, padx=5, pady=0)
+        self._lbl_pynmea2_version.grid(column=0, row=4, padx=5, pady=0)
+        self._lbl_pyubx2_version.grid(column=0, row=5, padx=5, pady=0)
+        self._lbl_copyright.grid(column=0, row=6, padx=5, pady=3)
+        self._btn_ok.grid(column=0, row=7, ipadx=3, ipady=3, padx=5, pady=3)
 
     def _attach_events(self):
         '''
